<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv_SE" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Theme Customizer</source>
        <translation>Theme Customizer</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Ok, thanks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Overwrite color preset?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color preset with this name already exists, do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Delete color preset?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Are you sure you want to delete this preset?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color presets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Save color preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Font</source>
        <translation>Teckensnitt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>Font size</source>
        <translation>Teckenstorlek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>DEFAULT</source>
        <translation>STANDARD</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <source>+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <source>+5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>Font colors</source>
        <translation>Teckensnittsfärger</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Primary font</source>
        <translation>Huvudtecken</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="242"/>
        <source>Secondary font</source>
        <translation>Andrahandstecken</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>Active font</source>
        <translation>Aktivt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Disabled font</source>
        <translation>Inaktivt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="360"/>
        <source>Painted font</source>
        <translation>Bakgrundsfärg</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button font</source>
        <translation>Knapp</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button pressed</source>
        <translation>Nedtryckt knapp</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>&quot;Paint&quot; color</source>
        <translation>Målad färg</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Icon theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Homescreen</source>
        <translation>Hemskärm</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Show app shortcut backgrounds</source>
        <translation>Visa genvägsbakgrund</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Snap-to-grid size</source>
        <translation>Fäst-mot-rutnät</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Widget opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>App shortcut size</source>
        <translation>Genvägsstorlek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <source>Web bookmark size</source>
        <translation>Bokmärkesstorlek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="721"/>
        <source>Reboot</source>
        <translation>Starta om</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <source>Auto-reboot after saving settings</source>
        <translation>Automatisk omstart efter sparade ändringar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="751"/>
        <location filename="mainwindow.cpp" line="352"/>
        <source>Apply changes</source>
        <translation>Genomför ändringar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Test</source>
        <translation>Testa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>Import fonts from MyDocs</source>
        <translation>Importera teckensnitt från MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="783"/>
        <source>Import all font files from MyDocs</source>
        <translation>Importera alla teckensnitt från MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Change backgrounds</source>
        <translation>Ändra bakgrund</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <source>Setting up the theme, please wait...</source>
        <translation>Ställer in tema...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Abort</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Searching and importing fonts, please wait...</source>
        <translation>Söker och importerar teckensnitt...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>Save and reboot</source>
        <translation>Spara och starta om</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - teckensnittimportering</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>Importera från MyDocs?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>Notera: Denna funktion kommer endast importera .ttf och .otf från mappen MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="370"/>
        <source>Importing fonts</source>
        <translation>Importerar teckensnitt</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>About Theme Customizer</source>
        <translation>Om Theme Customizer</translation>
    </message>
</context>
<context>
    <name>backgrounds</name>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>App Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Media Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Lockscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Tap me to change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Set image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Backgrounds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>savepreset</name>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset as...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>managepresets</name>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Choose color preset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Currently active colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Manage color presets</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
